@@ -75,7 +75,8 @@ roundit <- function(age,err,sigdig=2){
         out <- signif(dat,sigdig)
     } else {
         nsmall <- max(0,-(trunc(log10(min.err))-sigdig))
-        out <- format(dat,digits=sigdig,nsmall=nsmall,trim=TRUE)
+        out <- format(dat,digits=sigdig,nsmall=nsmall,
+                      trim=TRUE,scientific=FALSE)
     }
     out
 }
@@ -395,7 +396,9 @@ nfact <- function(alpha){
     stats::qnorm(1-alpha/2)
 }
 tfact <- function(alpha,df){
-    stats::qt(1-alpha/2,df=df)
+    if (df>0) out <- stats::qt(1-alpha/2,df=df)
+    else out <- 1.96
+    out
 }
 
 mymtext <- function(text,line=0,...){
